@@ -5,27 +5,22 @@ use warnings;
 use Carp qw/croak/;
 use XSLoader;
 
-our $VERSION = '2.070_103'; # Don't forget to update the TestCompat set for testing against installed encoders!
-our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
+our $VERSION = '2.01'; # Don't forget to update the TestCompat set for testing against installed encoders!
 
 # not for public consumption, just for testing.
 (my $num_version = $VERSION) =~ s/_//;
-my $TestCompat = [ map sprintf("%.2f", $_/100), reverse( 207 .. int($num_version * 100) ) ]; # compat with 2.07 to ...
+my $TestCompat = [ map sprintf("%.2f", $_/100), reverse( 200 .. int($num_version * 100) ) ]; # compat with 2.00 to ...
 sub _test_compat {return(@$TestCompat, $VERSION)}
 
 use Exporter 'import';
-our @EXPORT_OK = qw(
-    decode_sereal looks_like_sereal decode_sereal_with_header_data
-    scalar_looks_like_sereal
-    sereal_decode_with_object sereal_decode_with_header_with_object
-);
+our @EXPORT_OK = qw(decode_sereal looks_like_sereal decode_sereal_with_header_data);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 # export by default if run from command line
 our @EXPORT = ((caller())[1] eq '-e' ? @EXPORT_OK : ());
 
 sub CLONE_SKIP { 1 }
 
-XSLoader::load('Sereal::Decoder', $XS_VERSION);
+XSLoader::load('Sereal::Decoder', $VERSION);
 
 1;
 
@@ -39,8 +34,7 @@ Sereal::Decoder - Fast, compact, powerful binary deserialization
 
 =head1 SYNOPSIS
 
-  use Sereal::Decoder
-    qw(decode_sereal sereal_decode_with_object scalar_looks_like_sereal);
+  use Sereal::Decoder qw(decode_sereal looks_like_sereal);
   
   my $decoder = Sereal::Decoder->new({...options...});
   
@@ -50,16 +44,12 @@ Sereal::Decoder - Fast, compact, powerful binary deserialization
   # or if you don't have references to the top level structure, this works, too:
   $structure = $decoder->decode($blob);
   
-  # alternatively functional interface: (See Sereal::Performance)
-  sereal_decode_with_object($decoder, $blob, $structure);
-  $structure = sereal_decode_with_object($decoder, $blob);
-
-  # much slower functional interface with no persistent objects:
+  # alternatively functional interface:
   decode_sereal($blob, {... options ...}, $structure);
   $structure = decode_sereal($blob, {... options ...});
   
   # Not a full validation, but just a quick check for a reasonable header:
-  my $is_likely_sereal = scalar_looks_like_sereal($some_string);
+  my $is_likely_sereal = looks_like_sereal($some_string);
   # or:
   $is_likely_sereal = $decoder->looks_like_sereal($some_string);
 
@@ -154,7 +144,7 @@ This means you can do this:
 
 =head2 decode
 
-Given a byte string of Sereal data, the C<decode> call deserializes that data
+Given a byte string of Sereal data, the C<decode> call derializes that data
 structure. The result can be obtained in one of two ways: C<decode> accepts
 a second parameter, which is a scalar to write the result to, AND C<decode>
 will return the resulting data structure.
@@ -220,19 +210,6 @@ For reference, sereal's magic string is a four byte string C<=srl>.
 
 =head1 EXPORTABLE FUNCTIONS
 
-=head2 sereal_decode_with_object
-
-The functional interface that is equivalent to using C<decode>.  Takes a
-decoder object reference as first argument, followed by a byte string
-to deserialize.  Optionally takes a third parameter, which is the output
-scalar to write to. See the documentation for C<decode> above for details.
-
-This functional interface is marginally faster than the OO interface
-since it avoids method resolution overhead and, on sufficiently modern
-Perl versions, can usually avoid subroutine call overhead. See
-L<Sereal::Performance> for a discussion on how to tune Sereal for maximum
-performance if you need to.
-
 =head2 decode_sereal
 
 The functional interface that is equivalent to using C<new> and C<decode>.
@@ -241,12 +218,12 @@ by a hash reference of options (see documentation for C<new()>). Finally,
 C<decode_sereal> supports a third parameter, which is the output scalar
 to write to. See the documentation for C<decode> above for details.
 
-This functional interface is significantly slower than the OO interface since
+The functional interface is marginally slower than the OO interface since
 it cannot reuse the decoder object.
 
-=head2 scalar_looks_like_sereal
+=head2 looks_like_sereal
 
-The functional interface that is equivalent to using C<looks_like_sereal>.
+Same as the object method of the same name.
 
 =head1 ROBUSTNESS
 
@@ -255,7 +232,7 @@ input data as reasonably possible. This means that it should never
 (though read on) segfault. It may, however, cause a large malloc
 to fail. Generally speaking, invalid data should cause a Perl-trappable
 exception. The one exception is that for Snappy-compressed Sereal documents,
-the Snappy library may cause segmentation faults (invalid reads or writes).
+the Snappy library may cause segmentation faults (invalid reads orwrites).
 This should only be a problem if you do not checksum your data (internal
 checksum support is a To-Do) or if you accept data from potentially
 malicious sources.
@@ -286,9 +263,11 @@ the C<FREEZE/THAW> mechanism, please refer to L<Sereal::Encoder>.
 
 =head1 PERFORMANCE
 
-Please refer to the L<Sereal::Performance> document
-that has more detailed information about Sereal performance and
-tuning thereof.
+The exact performance in time and space depends heavily on the data structure
+to be serialized. For ready-made comparison scripts, see the
+F<author_tools/bench.pl> and F<author_tools/dbench.pl> programs that are part
+of this distribution. Suffice to say that this library is easily competitive
+in both time and space efficiency with the best alternatives.
 
 =head1 THREAD-SAFETY
 
@@ -311,7 +290,7 @@ L<https://groups.google.com/forum/?fromgroups#!forum/sereal-announce>
 Sereal development list:
 L<https://groups.google.com/forum/?fromgroups#!forum/sereal-dev>
 
-=head1 AUTHORS AND CONTRIBUTORS
+=head1 AUTHORS
 
 Yves Orton E<lt>demerphq@gmail.comE<gt>
 
@@ -323,14 +302,8 @@ Rafaël Garcia-Suarez
 
 Ævar Arnfjörð Bjarmason E<lt>avar@cpan.orgE<gt>
 
-Tim Bunce
-
 Daniel Dragan E<lt>bulkdd@cpan.orgE<gt> (Windows support and bugfixes)
 
-Zefram
-
-Borislav Nikolov
-
 Some inspiration and code was taken from Marc Lehmann's
 excellent JSON::XS module due to obvious overlap in
 problem domain.
@@ -344,8 +317,8 @@ their gratitude.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012, 2013, 2014 by Steffen Mueller
-Copyright (C) 2012, 2013, 2014 by Yves Orton
+Copyright (C) 2012, 2013 by Steffen Mueller
+Copyright (C) 2012, 2013 by Yves Orton
 
 The license for the code in this distribution is the following,
 with the exceptions listed below:
